==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/reactor/Reactor.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Reactor.h"
#include "ReactorHelpers.h"
#include <ace/config.h>
#include <boost/static_assert.hpp>
#include <cstring>

using namespace std;
using namespace ReactorHelpers;


Reactor::~Reactor()
{
}


/*=========================== ReactorHandlerId ==========================*/

ReactorHandlerId::ReactorHandlerId()
{
	typedef HandlerRepository::iterator Rep;
	memset(opaque, 0, sizeof(opaque));
	new(opaque) Rep();
}

ReactorHandlerId::ReactorHandlerId(ReactorHandlerId const& other)
{
	typedef HandlerRepository::iterator Rep;
	new(opaque) Rep(other.rep<Rep>());
}

ReactorHandlerId::~ReactorHandlerId()
{
	typedef HandlerRepository::iterator Rep;
	BOOST_STATIC_ASSERT(sizeof(opaque) >= sizeof(Rep));
	rep<Rep>().~Rep();
}

ReactorHandlerId&
ReactorHandlerId::operator=(ReactorHandlerId const& other)
{
	typedef HandlerRepository::iterator Rep;
	rep<Rep>() = other.rep<Rep>();
	return *this;
}

bool
ReactorHandlerId::operator==(ReactorHandlerId const& other) const
{
	typedef HandlerRepository::iterator Rep;
	return rep<Rep>() == other.rep<Rep>();
}


/*============================ ReactorTimerId ===========================*/

ReactorTimerId::ReactorTimerId()
{
	typedef TimerQueue::iterator Rep;
	memset(opaque, 0, sizeof(opaque));
	new(opaque) Rep();
}

ReactorTimerId::ReactorTimerId(ReactorTimerId const& other)
{
	typedef TimerQueue::iterator Rep;
	new(opaque) Rep(other.rep<Rep>());
}

ReactorTimerId::~ReactorTimerId()
{
	typedef TimerQueue::iterator Rep;
	BOOST_STATIC_ASSERT(sizeof(opaque) >= sizeof(Rep));
	rep<Rep>().~Rep();
}

ReactorTimerId&
ReactorTimerId::operator=(ReactorTimerId const& other)
{
	typedef TimerQueue::iterator Rep;
	rep<Rep>() = other.rep<Rep>();
	return *this;
}

bool
ReactorTimerId::operator==(ReactorTimerId const& other) const
{
	typedef TimerQueue::iterator Rep;
	return rep<Rep>() == other.rep<Rep>();
}

==> bfilter_1.1.4.orig.tar.gz: bfilter-1.1.4/reactor/Reactor.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Reactor.h"
#include "ReactorHelpers.h"
#include <ace/config-lite.h>
#include <boost/static_assert.hpp>
#include <cstring>

using namespace std;
using namespace ReactorHelpers;


Reactor::~Reactor()
{
}


/*=========================== ReactorHandlerId ==========================*/

ReactorHandlerId::ReactorHandlerId()
{
	typedef HandlerRepository::iterator Rep;
	memset(&opaque, 0, sizeof(storage));
	new(&opaque) Rep();
}

ReactorHandlerId::ReactorHandlerId(ReactorHandlerId const& other)
{
	typedef HandlerRepository::iterator Rep;
	new(&opaque) Rep(other.rep<Rep>());
}

ReactorHandlerId::~ReactorHandlerId()
{
	typedef HandlerRepository::iterator Rep;
	BOOST_STATIC_ASSERT(sizeof(storage) >= sizeof(Rep));
	rep<Rep>().~Rep();
}

ReactorHandlerId&
ReactorHandlerId::operator=(ReactorHandlerId const& other)
{
	typedef HandlerRepository::iterator Rep;
	rep<Rep>() = other.rep<Rep>();
	return *this;
}

bool
ReactorHandlerId::operator==(ReactorHandlerId const& other) const
{
	typedef HandlerRepository::iterator Rep;
	return rep<Rep>() == other.rep<Rep>();
}


/*============================ ReactorTimerId ===========================*/

ReactorTimerId::ReactorTimerId()
{
	typedef TimerQueue::iterator Rep;
	memset(&opaque, 0, sizeof(storage));
	new(&opaque) Rep();
}

ReactorTimerId::ReactorTimerId(ReactorTimerId const& other)
{
	typedef TimerQueue::iterator Rep;
	new(&opaque) Rep(other.rep<Rep>());
}

ReactorTimerId::~ReactorTimerId()
{
	typedef TimerQueue::iterator Rep;
	BOOST_STATIC_ASSERT(sizeof(storage) >= sizeof(Rep));
	rep<Rep>().~Rep();
}

ReactorTimerId&
ReactorTimerId::operator=(ReactorTimerId const& other)
{
	typedef TimerQueue::iterator Rep;
	rep<Rep>() = other.rep<Rep>();
	return *this;
}

bool
ReactorTimerId::operator==(ReactorTimerId const& other) const
{
	typedef TimerQueue::iterator Rep;
	return rep<Rep>() == other.rep<Rep>();
}
